@@ -13,6 +13,7 @@ from functools import wraps
 import time
 import json
 import binascii
+import importlib
 from collections import OrderedDict
 
 #import logging
@@ -41,7 +42,7 @@ class SuggResult:
 
     def __init__ (self, sWord, nDistLimit=-1):
         self.sWord = sWord
-        self.sSimplifiedWord = cp.simplifyWord(sWord)
+        self.sSimplifiedWord = st.simplifyWord(sWord)
         self.nDistLimit = nDistLimit  if nDistLimit >= 0  else  (len(sWord) // 3) + 1
         self.nMinDist = 1000
         self.aSugg = set()
@@ -55,7 +56,9 @@ class SuggResult:
             return
         self.aAllSugg.add(sSugg)
         if sSugg not in self.aSugg:
-            nDist = st.distanceDamerauLevenshtein(self.sSimplifiedWord, cp.simplifyWord(sSugg))
+            #nDist = min(st.distanceDamerauLevenshtein(self.sWord, sSugg), st.distanceDamerauLevenshtein(self.sSimplifiedWord, st.simplifyWord(sSugg)))
+            nDist = st.distanceDamerauLevenshtein(self.sSimplifiedWord, st.simplifyWord(sSugg))
+            #logging.info((nDeep * "  ") + "__" + sSugg + "__ :" + self.sSimplifiedWord +"|"+ st.simplifyWord(sSugg) +" -> "+ str(nDist))
             if nDist <= self.nDistLimit:
                 if " " in sSugg:
                     nDist += 1
@@ -69,16 +72,17 @@ class SuggResult:
 
     def getSuggestions (self, nSuggLimit=10):
         "return a list of suggestions"
+        # we sort the better results with the original word
         if self.dSugg[0]:
-            # we sort the better results with the original word
             self.dSugg[0].sort(key=lambda sSugg: st.distanceDamerauLevenshtein(self.sWord, sSugg))
+        elif self.dSugg[1]:
+            self.dSugg[1].sort(key=lambda sSugg: st.distanceDamerauLevenshtein(self.sWord, sSugg))
         lRes = self.dSugg.pop(0)
         for nDist, lSugg in self.dSugg.items():
             if nDist <= self.nDistLimit:
                 lRes.extend(lSugg)
                 if len(lRes) > nSuggLimit:
                     break
-        lRes = list(cp.filterSugg(lRes))
         if self.sWord.isupper():
             lRes = list(OrderedDict.fromkeys(map(lambda sSugg: sSugg.upper(), lRes))) # use dict, when Python 3.6+
         elif self.sWord[0:1].isupper():
@@ -150,6 +154,14 @@ class IBDAWG:
         self.bAcronymValid = False
         self.bNumAtLastValid = False
 
+        # lexicographer module ?
+        self.lexicographer = None
+        try:
+            self.lexicographer = importlib.import_module("graphspell.lexgraph_"+self.sLangCode)
+        except ImportError:
+            print("# No module <graphspell.lexgraph_"+self.sLangCode+".py>")
+
+
     def _initBinary (self):
         "initialize with binary structure file"
         if self.by[0:17] != b"/grammalecte-fsa/":
@@ -244,7 +256,7 @@ class IBDAWG:
 
     def isValidToken (self, sToken):
         "checks if <sToken> is valid (if there is hyphens in <sToken>, <sToken> is split, each part is checked)"
-        sToken = cp.spellingNormalization(sToken)
+        sToken = st.spellingNormalization(sToken)
         if self.isValid(sToken):
             return True
         if "-" in sToken:
@@ -288,7 +300,7 @@ class IBDAWG:
 
     def getMorph (self, sWord):
         "retrieves morphologies list, different casing allowed"
-        sWord = cp.spellingNormalization(sWord)
+        sWord = st.spellingNormalization(sWord)
         l = self.morph(sWord)
         if sWord[0:1].isupper():
             l.extend(self.morph(sWord.lower()))
@@ -300,8 +312,11 @@ class IBDAWG:
     def suggest (self, sWord, nSuggLimit=10, bSplitTrailingNumbers=False):
         "returns a set of suggestions for <sWord>"
         sWord = sWord.rstrip(".")   # useful for LibreOffice
-        sWord = cp.spellingNormalization(sWord)
-        sPfx, sWord, sSfx = cp.cut(sWord)
+        sWord = st.spellingNormalization(sWord)
+        sPfx = ""
+        sSfx = ""
+        if self.lexicographer:
+            sPfx, sWord, sSfx = self.lexicographer.split(sWord)
         nMaxSwitch = max(len(sWord) // 3, 1)
         nMaxDel = len(sWord) // 5
         nMaxHardRepl = max((len(sWord) - 5) // 4, 1)
@@ -312,6 +327,8 @@ class IBDAWG:
         self._splitSuggest(oSuggResult, sWord)
         self._suggest(oSuggResult, sWord, nMaxSwitch, nMaxDel, nMaxHardRepl, nMaxJump)
         aSugg = oSuggResult.getSuggestions(nSuggLimit)
+        if self.lexicographer:
+            aSugg = self.lexicographer.filterSugg(aSugg)
         if sSfx or sPfx:
             # we add what we removed
             return list(map(lambda sSug: sPfx + sSug + sSfx, aSugg))
@@ -320,7 +337,7 @@ class IBDAWG:
     def _splitTrailingNumbers (self, oSuggResult, sWord):
         m = re.match(r"(\D+)([0-9]+)$", sWord)
         if m and m.group(1)[-1:].isalpha():
-            oSuggResult.addSugg(m.group(1) + " " + cp.numbersToExponent(m.group(2)))
+            oSuggResult.addSugg(m.group(1) + " " + st.numbersToExponent(m.group(2)))
 
     def _splitSuggest (self, oSuggResult, sWord):
         # split at apostrophes
@@ -341,9 +358,9 @@ class IBDAWG:
                 return
             if (len(sNewWord) + len(sRemain) == len(oSuggResult.sWord)) and oSuggResult.sWord.lower().startswith(sNewWord.lower()) and self.isValid(sRemain):
                 if self.sLangCode == "fr" and sNewWord.lower() in ("l", "d", "n", "m", "t", "s", "c", "j", "qu", "lorsqu", "puisqu", "quoiqu", "jusqu", "quelqu") and sRemain[0:1] in cp.aVowel:
-                    oSuggResult.addSugg(sNewWord+"’"+sRemain)
+                    oSuggResult.addSugg(sNewWord+"’"+sRemain, nDeep)
                 if (len(sNewWord) > 1 and len(sRemain) > 1) or sNewWord in "aày" or sRemain in "aày":
-                    oSuggResult.addSugg(sNewWord+" "+sRemain)
+                    oSuggResult.addSugg(sNewWord+" "+sRemain, nDeep)
         if nDist > oSuggResult.nDistLimit:
             return
         cCurrent = sRemain[0:1]
@@ -408,7 +425,7 @@ class IBDAWG:
 
     def drawPath (self, sWord, iAddr=0):
         "show the path taken by <sWord> in the graph"
-        sWord = cp.spellingNormalization(sWord)
+        sWord = st.spellingNormalization(sWord)
         c1 = sWord[0:1]  if sWord  else " "
         iPos = -1
         n = 0
